#include "about.h"
#include "ui_about.h"

About::About(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::About)

{
    ui->setupUi(this);

    ui->icon->setPixmap(QPixmap("/usr/share/icons/hicolor/64x64/apps/bander64.png"));
    QFont f = ui->text1->font();
    f.setPointSize( f.pointSize() + 5 );
    f.setBold(true);
    QFont g = ui->text1->font();
    g.setPointSize( g.pointSize() - 1);
    QFont h = ui->text1->font();
    h.setPointSize( h.pointSize() - 3);


    //Set Font Sizes
    ui->bander->setFont(f);
    ui->text2->setFont(g);
    ui->text3->setFont(h);

    ui->bander->setText("bander 0.0.6");
    ui->text1->setText(tr("Electronic Components Helper"));
    ui->text2->setText("(C) 2013-2014 sixwheeledbeast & pichlo");
    ui->text3->setText(tr("Icons provided under Creative Commons license by Gentleface"));
}

About::~About()
{
    delete ui;
}

